pycocoa.apps.Tile

Package pycocoa :: Module apps :: Class Tile |
[frames] | no frames]

# Class Tile

      object --+
               |
    bases._Type0 --+
                   |
        bases._Type1 --+
                       |
            bases._Type2 --+
                           |
                          Tile

Dock tile for an App, wrapping an ObjC `NSDockTile`.

Instance Methods
__init__(self, app) New dock Tile. |
Inherited from `bases._Type2`: `__str__` Inherited from `bases._Type0`: `__repr__`, `type2strepr` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| label Get the badge text of the app's dock tile (`str`).
Inherited from `bases._Type2`: `title` Inherited from `bases._Type1`: `NSdelegate`, `app` Inherited from `bases._Type0`: `NS`, `NSDelegate` Inherited from `object`: `__class__`

Method Details

### __init__(self, app) (Constructor) |
New dock Tile. Parameters: `app` - The app (App). Overrides: object.__init__

Property Details

### label Get the badge text of the app's dock tile (`str`). Get Method: label(self) - Get the badge text of the app's dock tile (`str`). Set Method: label(self, label) - Set the badge text of the app's dock tile (`str`).